# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.5.1] - 2025-02-13

### Fixed

- Corrected `_parse_distributions` of `ODSHDCATdeProfile` to not rely on resource dict, fixing missing `id` errors.
- Resolved an issue where harvested datasets were incorrectly required to have a category set, even when the configuration variable `ckanext.odsh.require_at_least_one_category` was set to false.

## [2.5.0] - 2025-01-30

### Fixed

- Corrected handling of file hash and size updates to ensure they are properly calculated during resource updates and added enhanced error handling for missing files or processing failures during file attribute updates.

### Removed

- Completely removed the legacy plugin responsible for creating thumbnails, including all associated code and functionality.

## [2.4.7] - 2025-01-20

### Added

- Added Matomo support to enable tracking and analytics. The following configuration variables were introduced:
  - `ckanext.odsh.matomo_enabled` (boolean): Enables or disables Matomo tracking. Default is `False`.
  - `ckanext.odsh.matomo_base_uri` (string): Specifies the base URI of the Matomo tracker. Default is `None`.
  - `ckanext.odsh.matomo_site_id` (string): Specifies the Matomo site ID for the instance. Default is `None`.
  
## [2.4.6] - 2025-01-09

### Added

- Added parsing logic for `politicalGeocodingURI` in `ODSHDCATdeProfile`.
  - If a dataset contains a `politicalGeocodingURI` but lacks a `spatial_uri`, the `politicalGeocodingURI` value is now extracted and used to populate the `spatial_uri` field in the dataset's extras.
  - This ensures that datasets with a political geocoding URI but without a spatial URI are handled correctly in the profile.

## [2.4.5] - 2024-12-17

### Added

- Added historical and regional political geocoding data for locations such as Eckernförde, Wandsbek, Altona, and Lübeck in `sh_bb.csv`. 

### Changed

- Updated `tag_name_validator` to replace newlines with whitespaces and ensure tags are non-empty during validation.
- Replaced `schema:startDate` with `dcat:startDate` and `schema:endDate` with `dcat:endDate` in test files.
- Changed order of entries for CC Zero and CC BY 4.0 in `licenses.json`.

## [2.4.4] 2024-09-23

### Added

- Added an alert in the dataset edit form if a GUID was detected in the dataset, advising users to avoid manual editing and to contact the publisher for any data change requests.

### Fixed

- Fix search input behavior to remember the last entered value.

## [2.4.3] - 2024-06-25

### Added

- Added a "Dashboard" link to the account navigation for quick access to the user dashboard.

### Removed

- Removed custom dashboard blueprint and associated view as these functionalities are covered by the default CKAN implementation.

### Fixed

- Added a check to ensure `data.id` is present before rendering the delete button in the dataset edit form. This prevents server errors when `data.id` is not available, e.g., for new datasets.

## [2.4.2] - 2024-06-21

### Fixed

- Resolved display issues of the resource view and share icons.
- Fixed display of dataset properties `version_notes` and `is_replaced_by` in view and RDF.

## [2.4.1] - 2024-05-16

### Added

- Hyphens now set to auto for all elements.
- Added description popovers to display information on the contact properties of a package.

### Fixed

- Resolved the issue with navbar rows incorrectly displaying side-by-side on larger screens.

## [2.4.0] - 2024-03-11

### Added

- Support for DCAT-AP properties `hvdCategory` (High Value Dataset) and `applicableLegislation`. Users can now categorize datasets as high value datasets and specify the applicable legislation governing the data.
- Introduced text ellipsis functionality to handle long dataset description texts and distribution descriptions.
- Enhanced dataset pages by displaying comprehensive contact information, including author, maintainer, creator, and contact person.
- Added dataset slug field in the dataset form.
- Added Apache Parquet file format to File Formats RDF file.

## [2.3.1] - 2023-12-01

### Added

- Municipality geometries for cities (Flensburg, Kiel, Lübeck, and Neumünster) have been incorporated into [sh_bb.csv](./ckanext/odsh/resources/sh_bb.csv).

### Removed

- The flash message for ODaG evaluation has been removed.

### Fixed

- The delete button for packages is now visible again. It was inadvertently missing in a previous update and has been rectified.

- Fixed missing license properties (`od_conformance`, `ods_conformance`) in the [license configuration](./ckanext/odsh/resources/licenses.json).

## [2.3.0] - 2023-11-21

### Added

- CSRF inputs are now included in template forms.
- Introducing a new helper function: `format_resource_format`. This function is used to format a resource format string.
- Resource descriptions are now displayed below the resource title in the resources list.

### Removed

- Completely removed data requests.
- Avoided the usage of the global context variable c where possible.
- Removed deprecated subject mappings JSON template.
- Removed deprecated activities feature (CKAN activities have been extracted into a separate activity plugin).

### Changed

- Updated minimum CKAN version requirement from `2.9` to `2.10`. Please run `ckan db upgrade` after updating.
- Replaced `is_okd_compliant` with `od_conformance` and `is_osi_compliant` with `osd_conformance` in the [licenses.json](./ckanext/odsh/resources/licenses.json) file.
- Deprecated methods replaced with their respective new versions from plugin interfaces:
  - `ckan.plugins.interfaces.IResourceController`:
    - Replaced `before_create` with `before_resource_create`
    - Replaced `after_create` with `after_resource_create`
    - Replaced `before_update` with `before_resource_update`
    - Replaced `after_update` with `after_resource_update`
    - Replaced `before_delete` with `before_resource_delete`
    - Replaced `after_delete` with `after_resource_delete`
    - Replaced `before_show` with `before_resource_show`
  - `ckan.plugins.interfaces.IPackageController`:
    - Replaced `after_create` with `after_dataset_create`
    - Replaced `after_update` with `after_dataset_update`
    - Replaced `after_delete` with `after_dataset_delete`
    - Replaced `after_show` with `after_dataset_show`
    - Replaced `before_search` with `before_dataset_search`
    - Replaced `after_search` with `after_dataset_search`
    - Replaced `before_index` with `before_dataset_index`
- Updated minimum version of ckanext-spatial extension to `2.0.0`.
- Moved `fanstatic` webassets to `assets` directory.

## [2.2.0] - 2023-07-24

### Added

- Added editing of custom extra fields alongside the fixed fields in organizations form.
- Added versioning information (`adms:versionNotes`, `dcterms:isReplacedBy`) in dataset form.

### Removed

- Removed language field from dataset form.

## [2.1.0] - 2023-07-10

### Added

- Added package-pill indicator for data series in the dataset overview.

### Removed

- Removed Travis CI `bin/` directory, along with all associated Travis CI configuration files and scripts.
- Removed the functionality that retrieved the current commit hash of the checked out Git repository for the extension. The commit hash was previously inserted into a custom API resource to provide external developers repository information.
- Removed `ckanext.odsh.home` configuration variable.
- Removed `ckanext.odsh.upload_formats` configuration variable. Upload formats are now populated by EU-approved file formats.
- Removed subject mappings and other subject related code used in Transparenzportal SH (TPSH).

### Changed

- Tag names are no longer restricted by strict validation checks, allowing for nearly unrestricted input (according [DCAT-AP](https://www.dcat-ap.de/def/dcatde/2.0/spec/#datensatz-schlagwort)).
- Reorganized default mapping and resource files for improved organization and maintenance. Mapping and config files (e.g., file formats) are now located in `ckanext/odsh/resources/`.
- Refactor distribution/resource editing form to replace free-text format field with select field populated by EU-approved file formats.
- Reorganized tests and helper TPSH specific code.
- Migrated TPSH helpers to `helpers.py`.
- Moved TPSH tests to `tests/` and legacy tests to `tests_wip`.

## [2.0.0] - 2023-06-08

### Added

- Custom `robots.txt` file.

### Changed

- Migrated controllers to blueprints (Pylons to Flask).
- UI and webasset upgrades.
- Nosetests changed to pytests.
- Updated file formats authority data.

### Removed

- Removed support for old CKAN versions prior 2.9.
- Python 2 support has been dropped to align with the latest standards and focus on Python 3 compatibility.
- ICAP support has been removed. Please note that the functionality associated with ICAP is no longer available.
- Matomo support has been discontinued. Matomo-related features will no longer be accessible.
- Master and slave operation support has been eliminated. The functionality for master and slave operations is no longer supported or available.

## [1.4.3] - 2022-11-03

### Added

- Added "Musterdatenkatalog" references to RDF.

## [1.4.2] - 2022-10-24

## [1.4.1] - 2022-08-17

## [1.4.0] - 2022-08-11
