import datetime
from mock import patch
import unittest

from ckanext.odsh.helpers import is_within_last_month, extract_email

class TestHelpers(unittest.TestCase):
    # is_within_last_month
    def test_within_last_month_with_same_month(self):
        date = datetime.date(2019, 4, 15)
        date_ref = datetime.date(2019, 4, 29)
        self.assertTrue(is_within_last_month(date, date_ref))

    def test_within_last_month_with_different_years(self):
        date = datetime.date(2018, 12, 16)
        date_ref = datetime.date(2019, 1, 15)
        self.assertTrue(is_within_last_month(date, date_ref))

    def test_within_last_month_with_different_months(self):
        date = datetime.date(2018, 6, 16)
        date_ref = datetime.date(2018, 7, 10)
        self.assertTrue(is_within_last_month(date, date_ref))

    def test_within_last_month_returns_false_for_invalid_dates(self):
        date = datetime.date(2018, 12, 15)
        date_ref = datetime.date(2019, 1, 15)
        self.assertFalse(is_within_last_month(date, date_ref))

    def test_within_last_month_returns_false_for_dates_in_different_months(self):
        date = datetime.date(2018, 6, 8)
        date_ref = datetime.date(2018, 7, 10)
        self.assertFalse(is_within_last_month(date, date_ref))

    def test_within_last_month_uses_today_if_date_ref_missing(self):
        date = datetime.date.today() - datetime.timedelta(days=20)
        self.assertTrue(is_within_last_month(date))

    # extract_email
    def test_extract_email_with_mailto_prefix(self):
        email = extract_email("mailto:user1@example.com")
        self.assertEqual(email, "user1@example.com")

    def test_extract_email_without_mailto_prefix(self):
        email = extract_email("user1@example.com")
        self.assertEqual(email, "user1@example.com")

    def test_extract_email_invalid_input(self):
        email = extract_email("thisisnomail")
        self.assertIsNone(email)

        email = extract_email(None)
        self.assertIsNone(email)

    def test_extract_email_multiple_emails(self):
        email = extract_email("Emails: user1@example.com, user2@example.com")
        self.assertEqual(email, "user1@example.com")

if __name__ == '__main__':
    unittest.main()